Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(905)

Unified Diff: pkg/dartino_compiler/lib/src/please_report_crash.dart

Issue 1659163007: Rename fletch -> dartino (Closed) Base URL: https://github.com/dartino/sdk.git@master
Patch Set: address comments Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/dartino_compiler/lib/src/please_report_crash.dart
diff --git a/pkg/fletchc/lib/src/please_report_crash.dart b/pkg/dartino_compiler/lib/src/please_report_crash.dart
similarity index 92%
rename from pkg/fletchc/lib/src/please_report_crash.dart
rename to pkg/dartino_compiler/lib/src/please_report_crash.dart
index 9b26e92626068091503bd693dc581edc7d26c2ac..dd6b9f9326c901e3defd055969c193edc249115c 100644
--- a/pkg/fletchc/lib/src/please_report_crash.dart
+++ b/pkg/dartino_compiler/lib/src/please_report_crash.dart
@@ -2,10 +2,10 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE.md file.
-library fletchc.please_report_crash;
+library dartino_compiler.please_report_crash;
import 'guess_configuration.dart' show
- fletchVersion;
+ dartinoVersion;
bool crashReportRequested = false;
@@ -23,7 +23,7 @@ Please include the following information:
* the name and version of your operating system
* the Dartino SDK version ($fletchVersion)
* the entire message you see here (including the full stack trace
below as well as the source location above)
@@ -39,7 +39,7 @@ Please include the following information:
* the name and version of your operating system
* the Dartino SDK version ($fletchVersion)
* the entire message you see here (including the full stack trace below)
""";
« no previous file with comments | « pkg/dartino_compiler/lib/src/model.dart ('k') | pkg/dartino_compiler/lib/src/shared_command_infrastructure.dart » ('j') | no next file with comments »
@@ -23,7 +23,7 @@ Please include the following information:
* the name and version of your operating system
-* the Dartino SDK version ($fletchVersion)
+* the Dartino SDK version ($dartinoVersion)
* the entire message you see here (including the full stack trace
below as well as the source location above)
@@ -39,7 +39,7 @@ Please include the following information:
* the name and version of your operating system
-* the Dartino SDK version ($fletchVersion)
+* the Dartino SDK version ($dartinoVersion)
* the entire message you see here (including the full stack trace below)
""";

Powered by Google App Engine
This is Rietveld 408576698